@@ -1,6 +1,6 @@
 from .core import timeout_handler, retry_function
 from .tools import send_request
-from .time_utils import time_log, time_diff, monitor_execution_time
+from .time_utils import time_log, time_diff, time_monitor
 from .printer import print_block, print_line, print_title
 
 __author__ = "ruocen"
@@ -12,7 +12,7 @@ __all__ = [
     "send_request",
     "time_log",
     "time_diff",
-    "monitor_execution_time",
+    "time_monitor",
     "print_block",
     "print_line",
     "print_title",
